@@ -1099,7 +1099,7 @@ Tokenizer_really_parse_entity(Tokenizer *self)
             }
             break;
         }
-        if (i == 0 && this == '0') {
+        if (i == 0 && numeric && this == '0') {
             zeroes++;
             self->head++;
             continue;
@@ -1770,6 +1770,7 @@ Tokenizer_really_parse_tag(Tokenizer *self)
         return NULL;
     }
     if (Tokenizer_check_route(self, LC_TAG_OPEN) < 0) {
+        TagData_dealloc(data);
         return NULL;
     }
     if (Tokenizer_push(self, LC_TAG_OPEN)) {
