@@ -27,6 +27,7 @@ import pytest
 from mwparserfromhell.nodes import Heading, Text
 from .conftest import assert_wikicode_equal, wrap, wraptext
 
+
 def test_str():
     """test Heading.__str__()"""
     node = Heading(wraptext("foobar"), 2)
@@ -34,6 +35,7 @@ def test_str():
     node2 = Heading(wraptext(" zzz "), 5)
     assert "===== zzz =====" == str(node2)
 
+
 def test_children():
     """test Heading.__children__()"""
     node = Heading(wrap([Text("foo"), Text("bar")]), 3)
@@ -42,11 +44,13 @@ def test_children():
     with pytest.raises(StopIteration):
         next(gen)
 
+
 def test_strip():
     """test Heading.__strip__()"""
     node = Heading(wraptext("foobar"), 3)
     assert "foobar" == node.__strip__()
 
+
 def test_showtree():
     """test Heading.__showtree__()"""
     output = []
@@ -56,10 +60,10 @@ def test_showtree():
     node2 = Heading(wraptext(" baz "), 4)
     node1.__showtree__(output.append, get, None)
     node2.__showtree__(output.append, get, None)
-    valid = ["===", (getter, node1.title), "===",
-             "====", (getter, node2.title), "===="]
+    valid = ["===", (getter, node1.title), "===", "====", (getter, node2.title), "===="]
     assert valid == output
 
+
 def test_title():
     """test getter/setter for the title attribute"""
     title = wraptext("foobar")
@@ -68,6 +72,7 @@ def test_title():
     node.title = "héhehé"
     assert_wikicode_equal(wraptext("héhehé"), node.title)
 
+
 def test_level():
     """test getter/setter for the level attribute"""
     node = Heading(wraptext("foobar"), 3)
